@@ -11,9 +11,9 @@ from ozcore.core.helpers import (
     now_prefix, # datetime str for now or today
     clean_html, # clean html and return markdown
     md_2_html, # convert markdown to html
-    translate, # translate text with Google,
     dirme, # lists methods of a given module
     serialize_a_json_field, # validate and join nodes of json or dict
+    unzip, # download and unzip a zip file
 )
 
 
